serbian_dict = {
    "А": "A",
    "Б": "B",
    "В": "V",
    "Г": "G",
    "Д": "D",
    "Ђ": "Đ",
    "Е": "E",
    "Ж": "Ž",
    "З": "Z",
    "И": "I",
    "Ј": "J",
    "К": "K",
    "Л": "L",
    "Љ": "Lj",
    "М": "M",
    "Н": "N",
    "Њ": "Nj",
    "О": "O",
    "П": "P",
    "Р": "R",
    "С": "S",
    "Т": "T",
    "Ћ": "Ć",
    "У": "U",
    "Ф": "F",
    "Х": "H",
    "Ц": "C",
    "Ч": "Č",
    "Џ": "Dž",
    "Ш": "Š",
    "а": "a",
    "б": "b",
    "в": "v",
    "г": "g",
    "д": "d",
    "ђ": "đ",
    "е": "e",
    "ж": "ž",
    "з": "z",
    "и": "i",
    "ј": "j",
    "к": "k",
    "л": "l",
    "љ": "lj",
    "м": "m",
    "н": "n",
    "њ": "nj",
    "о": "o",
    "ô": "ô",
    "п": "p",
    "р": "r",
    "с": "s",
    "т": "t",
    "ћ": "ć",
    "у": "u",
    "ф": "f",
    "х": "h",
    "ц": "c",
    "ч": "č",
    "џ": "dž",
    "ш": "š"
}

serbian_to_lat_dict = {y: x for x, y in iter(serbian_dict.items())}

# Function to iterate through characters - if character in dict, swap for
# corresponding key


def translate_from_dict(original_text, dictionary_of_translations):
    out = original_text
    for target in dictionary_of_translations:
        trans = str.maketrans(target, dictionary_of_translations[target])
        out = out.translate(trans)
    return out

# Output a list of sentences from a string


def string_to_list(input_string):
    import nltk.tokenize
    from nltk.tokenize import sent_tokenize, word_tokenize
    output = sent_tokenize(input_string)
    return output

# Tokenize string into sentences and transliterate from Serbian to the
# Latin alphabet using the dictionary above


def serb_translit_sents(input_string):
    import re

    def serb_translate(x): return ''.join([serbian_dict[i] for i in x])

    text = string_to_list(input_string)

    translated_full = []
    for txt in text:
        list_of_translated = []
        words = re.split(r'(\s+)', txt)
        for word in words:
            word_list = []
            for letter in word:
                if letter in serbian_dict:
                    translated = serb_translate(letter)
                    word_list.append(translated)
                else:
                    word_list.append(letter)
            list_of_translated.append(''.join(word_list))
        translated_full.append(''.join(list_of_translated))

    transliterated_sents = translated_full
    return transliterated_sents

# Transliterate from Serbian to the Latin alphabet using the dictionary above


def serb_translit(input):
    import re

    def serb_translate(x): return ''.join([serbian_dict[i] for i in x])

    if isinstance(input, str):
        text = input
        translated_full = []
        list_of_translated = []
        words = re.split(r'(\s+)', text)
        for word in words:
            word_list = []
            for letter in word:
                if letter in serbian_dict:
                    translated = serb_translate(letter)
                    word_list.append(translated)
                else:
                    word_list.append(letter)
            list_of_translated.append(''.join(word_list))
        translated_full.append(''.join(list_of_translated))

        transliterated_sents = ' '.join(translated_full)
        return transliterated_sents

    elif isinstance(input, list):
        text = []
        for el in input:
            text.append(el)
        translated_full = []
        for txt in text:
            list_of_translated = []
            words = re.split(r'(\s+)', txt)
            for word in words:
                word_list = []
                for letter in word:
                    if letter in serbian_dict:
                        translated = serb_translate(letter)
                        word_list.append(translated)
                    else:
                        word_list.append(letter)
                list_of_translated.append(''.join(word_list))
            translated_full.append(''.join(list_of_translated))

        transliterated_sents = ' '.join(translated_full)
        return transliterated_sents

# Tokenize a string into sentences and transliterate from the Latin
# alphabet to Serbian


def latin_to_serb_sents(input_string):
    import re

    def serb_translatinate(x): return ''.join(
        [serbian_to_lat_dict[i] for i in x])
    text = string_to_list(input_string)
    translatinated_full = []
    for txt in text:
        list_of_translatinated = []
        words = re.split(r'(\s+)', txt)
        for w in words:
            word_list = []

            for i, j, in enumerate(w):
                # making sure letters we're checking for are within the list's
                # range
                if j == "l":
                    if 0 <= i + 1 < len(w):
                        if w[i + 1] == "j":
                            word_list.append("љ")
                    else:
                        word_list.append("л")
                elif j == "L":
                    if 0 <= i + 1 < len(w):
                        if w[i + 1] == "j":
                            word_list.append("Љ")
                    else:
                        word_list.append("Л")

                if j == "n":
                    if 0 <= i + 1 < len(w):
                        if w[i + 1] == "j":
                            word_list.append("њ")
                    else:
                        word_list.append("н")

                elif j == "N":
                    if 0 <= i + 1 < len(w):
                        if w[i + 1] == "j":
                            word_list.append("Њ")
                    else:
                        word_list.append("Н")

                if j == "d":
                    if 0 <= i + 1 < len(w):
                        if w[i + 1] == "ž":
                            word_list.append("џ")
                    else:
                        word_list.append("д")
                elif j == "D":
                    if 0 <= i + 1 < len(w):
                        if w[i + 1] == "ž":
                            word_list.append("Џ")
                    else:
                        word_list.append("Д")

                elif j in serbian_to_lat_dict:
                    translatinated = serb_translatinate(j)
                    word_list.append(translatinated)
                else:
                    word_list.append(j)

            list_of_translatinated.append(''.join(word_list))
        translatinated_full.append(''.join(list_of_translatinated))

    transliterated_sents = translatinated_full
    return transliterated_sents

# Transliterate from Serbian to the Latin alphabet


def latin_to_serb(input):
    import re

    def serb_translatinate(x): return ''.join(
        [serbian_to_lat_dict[i] for i in x])

    if isinstance(input, str):
        text = input
        translatinated_full = []
        list_of_translatinated = []
        words = re.split(r'(\s+)', text)
        for w in words:
            word_list = []

            for i, j, in enumerate(w):
                # making sure letters we're checking for are within the list's
                # range
                if j == "l":
                    if 0 <= i + 1 < len(w):
                        if w[i + 1] == "j":
                            word_list.append("љ")
                    else:
                        word_list.append("л")
                elif j == "L":
                    if 0 <= i + 1 < len(w):
                        if w[i + 1] == "j":
                            word_list.append("Љ")
                    else:
                        word_list.append("Л")

                if j == "n":
                    if 0 <= i + 1 < len(w):
                        if w[i + 1] == "j":
                            word_list.append("њ")
                    else:
                        word_list.append("н")

                elif j == "N":
                    if 0 <= i + 1 < len(w):
                        if w[i + 1] == "j":
                            word_list.append("Њ")
                    else:
                        word_list.append("Н")

                if j == "d":
                    if 0 <= i + 1 < len(w):
                        if w[i + 1] == "ž":
                            word_list.append("џ")
                    else:
                        word_list.append("д")
                elif j == "D":
                    if 0 <= i + 1 < len(w):
                        if w[i + 1] == "ž":
                            word_list.append("Џ")
                    else:
                        word_list.append("Д")

                elif j in serbian_to_lat_dict:
                    translatinated = serb_translatinate(j)
                    word_list.append(translatinated)
                else:
                    word_list.append(j)

            list_of_translatinated.append(''.join(word_list))
        translatinated_full.append(''.join(list_of_translatinated))

        transliterated_sents = ' '.join(translatinated_full)
        return transliterated_sents

    elif isinstance(input, list):
        translatinated_full = []
        list_of_translatinated = []
        for txt in input:
            list_of_translatinated = []
            words = re.split(r'(\s+)', txt)
            for w in words:
                word_list = []

                for i, j, in enumerate(w):
                    # making sure letters we're checking for are within the
                    # list's range
                    if j == "l":
                        if 0 <= i + 1 < len(w):
                            if w[i + 1] == "j":
                                word_list.append("љ")
                    elif j == "L":
                        if 0 <= i + 1 < len(w):
                            if w[i + 1] == "j":
                                word_list.append("Љ")

                    if j == "n":
                        if 0 <= i + 1 < len(w):
                            if w[i + 1] == "j":
                                word_list.append("њ")
                    elif j == "N":
                        if 0 <= i + 1 < len(w):
                            if w[i + 1] == "j":
                                word_list.append("Њ")

                    if j == "d":
                        if 0 <= i + 1 < len(w):
                            if w[i + 1] == "ž":
                                word_list.append("џ")
                    elif j == "D":
                        if 0 <= i + 1 < len(w):
                            if w[i + 1] == "ž":
                                word_list.append("Џ")

                    elif j == "c":
                        if 0 <= i + 1 < len(w):
                            if w[i + 1] == "h":
                                if w[i - 2] != "s" and w[i - 2] != "S":
                                    word_list.append("ч")
                    elif j == "C":
                        if 0 <= i + 1 < len(w):
                            if w[i + 1] == "h":
                                word_list.append("Ч")

                    elif 0 <= i + 3 < len(w):
                        if j == "s":
                            if w[i + 1] == "h":
                                if w[i + 2] == "c":
                                    if w[i + 3] == "h":
                                        word_list.append("щ")
                                else:
                                    if w[i + 1] == "h":
                                        word_list.append("ш")
                        if j == "S":
                            if w[i + 1] == "h":
                                if w[i + 2] == "c":
                                    if w[i + 3] == "h":
                                        word_list.append("Щ")
                            else:
                                if w[i + 1] == "h":
                                    word_list.append("Ш")
                    elif j == 'h':
                        if i != 0:
                            if [i - 1] == 'c':
                                word_list.append("ч")

                            elif [i - 1] == 'C':
                                word_list.append("Ч")
                        else:
                            translatinated = serb_translatinate(j)
                            word_list.append(translatinated)

                    elif j in serbian_to_lat_dict:
                        translatinated = serb_translatinate(j)
                        word_list.append(translatinated)
                    else:
                        word_list.append(j)

                list_of_translatinated.append(''.join(word_list))
            translatinated_full.append(''.join(list_of_translatinated))

        transliterated_sents = ' '.join(translatinated_full)
        return transliterated_sents



carp_dict = {
    "А": "A",
    "Б": "B",
    "В": "V",
    "Г": "H",
    "Ґ": "G",
    "Д": "D",
    "Е": "E",
    "Є": "I͡E",
    "Ё": "Ë",
    "Ж": "Z͡H",
    "З": "Z",
    "І": "I",
    "Ї": "Ї",
    "И": "Y",
    "Ы": "Ŷ",
    "Й": "Ĭ",
    "К": "K",
    "Л": "L",
    "М": "M",
    "Н": "N",
    "О": "O",
    "Ô": "Ô",
    "П": "P",
    "Р": "R",
    "С": "S",
    "Т": "T",
    "У": "U",
    "Ф": "F",
    "Х": "K͡H",
    "Ц": "T͡S",
    "Ч": "Ch",
    "Ш": "Sh",
    "Щ": "Shch",
    "Э": "Ė",
    "Ю": "I͡U",
    "Я": "I͡A",
    "Ь": "'",
    "Ъ": '"',
    "Ѣ": "Î",
    "а": "a",
    "б": "b",
    "в": "v",
    "г": "h",
    "ґ": "g",
    "д": "d",
    "е": "e",
    "є": "i͡e",
    "ё": "ё",
    "ж": "z͡h",
    "з": "z",
    "i": "i",
    "ї": "ї",
    "и": "y",
    "ы": "ŷ",
    "й": "ĭ",
    "к": "k",
    "л": "l",
    "м": "m",
    "н": "n",
    "о": "o",
    "ô": "ô",
    "п": "p",
    "р": "r",
    "с": "s",
    "т": "t",
    "у": "u",
    "ф": "f",
    "х": "k͡h",
    "ц": "t͡s",
    "ч": "ch",
    "ш": "sh",
    "щ": "shch",
    "э": "ė",
    "ю": "i͡u",
    "я": "i͡a",
    "ь": "ʹ",
    "ъ": 'ʺ',
    "ѣ": "î"
}

carp_to_lat_dict = {y: x for x, y in iter(carp_dict.items())}

# Function to iterate through characters - if character in dict, swap for
# corresponding key


def translate_from_dict(original_text, dictionary_of_translations):
    out = original_text
    for target in dictionary_of_translations:
        trans = str.maketrans(target, dictionary_of_translations[target])
        out = out.translate(trans)
    return out

# Output a list of sentences from a string


def string_to_list(input_string):
    import nltk.tokenize
    from nltk.tokenize import sent_tokenize, word_tokenize
    output = sent_tokenize(input_string)
    return output

# Tokenize string into sentences and transliterate from Carpatho-Rusyn to
# the Latin alphabet using the dictionary above


def carp_translit_sents(input_string):
    import re

    def carp_translate(x): return ''.join([carp_dict[i] for i in x])

    text = string_to_list(input_string)

    translated_full = []
    for txt in text:
        list_of_translated = []
        words = re.split(r'(\s+)', txt)
        for word in words:
            word_list = []
            for letter in word:
                if letter in carp_dict:
                    translated = carp_translate(letter)
                    word_list.append(translated)
                else:
                    word_list.append(letter)
            list_of_translated.append(''.join(word_list))
        translated_full.append(''.join(list_of_translated))

    transliterated_sents = translated_full
    return transliterated_sents

# Transliterate from Carpatho-Rusyn to the Latin alphabet using the
# dictionary above


def carp_translit(input):
    import re

    def carp_translate(x): return ''.join([carp_dict[i] for i in x])

    if isinstance(input, str):
        text = input
        translated_full = []
        list_of_translated = []
        words = re.split(r'(\s+)', text)
        for word in words:
            word_list = []
            for letter in word:
                if letter in carp_dict:
                    translated = carp_translate(letter)
                    word_list.append(translated)
                else:
                    word_list.append(letter)
            list_of_translated.append(''.join(word_list))
        translated_full.append(''.join(list_of_translated))

        transliterated_sents = ' '.join(translated_full)
        return transliterated_sents

    elif isinstance(input, list):
        text = []
        for el in input:
            text.append(el)
        translated_full = []
        for txt in text:
            list_of_translated = []
            words = re.split(r'(\s+)', txt)
            for word in words:
                word_list = []
                for letter in word:
                    if letter in carp_dict:
                        translated = carp_translate(letter)
                        word_list.append(translated)
                    else:
                        word_list.append(letter)
                list_of_translated.append(''.join(word_list))
            translated_full.append(''.join(list_of_translated))

        transliterated_sents = ' '.join(translated_full)
        return transliterated_sents

# Tokenize a string into sentences and transliterate from the Latin
# alphabet to Carpatho-Rusyn


def latin_to_carp_sents(input_string):
    import re

    def carp_translatinate(x): return ''.join([carp_to_lat_dict[i] for i in x])
    text = string_to_list(input_string)
    translatinated_full = []
    for txt in text:
        list_of_translatinated = []
        words = re.split(r'(\s+)', txt)
        for w in words:
            word_list = []

            for i, j, in enumerate(w):
                # making sure letters we're checking for are within the list's
                # range
                if j == u"\u0361":
                    if 0 <= i + 1 < len(w):
                        if w[i - 1] == "t" and w[i + 1] == "s":
                            word_list.append("ц")
                        elif w[i - 1] == "T" and w[i + 1] == "S":
                            word_list.append("Ц")

                        elif w[i - 1] == "i" and w[i + 1] == "e":
                            word_list.append("є")
                        elif w[i - 1] == "I" and w[i + 1] == "E":
                            word_list.append("Є")

                        elif w[i - 1] == "i" and w[i + 1] == "u":
                            word_list.append("ю")
                        elif w[i - 1] == "I" and w[i + 1] == "U":
                            word_list.append("Ю")

                        elif w[i - 1] == "i" and w[i + 1] == "a":
                            word_list.append("я")
                        elif w[i - 1] == "I" and w[i + 1] == "A":
                            word_list.append("Я")

                        elif w[i - 1] == "z" and w[i + 1] == "h":
                            word_list.append("ж")
                        elif w[i - 1] == "Z" and w[i + 1] == "H":
                            word_list.append("Ж")

                        elif w[i - 1] == "k" and w[i + 1] == "h":
                            word_list.append("х")
                        elif w[i - 1] == "K" and w[i + 1] == "H":
                            word_list.append("Х")

                elif j == "c":
                    if 0 <= i + 1 < len(w):
                        if w[i + 1] == "h":
                            if w[i - 2] != "s" and w[i - 2] != "S":
                                word_list.append("ч")
                elif j == "C":
                    if 0 <= i + 1 < len(w):
                        if w[i + 1] == "h":
                            word_list.append("Ч")

                elif j == "s":
                    if 0 <= i + 3 < len(w):
                        if w[i + 1] == "h":
                            if w[i + 2] == "c":
                                if w[i + 3] == "h":
                                    word_list.append("щ")
                            else:
                                if w[i + 1] == "h":
                                    word_list.append("ш")
                                else:
                                    word_list.append("c")
                        else:
                            word_list.append("c")

                    else:
                        word_list.append("c")

                elif j == "S":
                    if w[i + 1] == "h":
                        if w[i + 2] == "c":
                            if w[i + 3] == "h":
                                word_list.append("Щ")
                    else:
                        if w[i + 1] == "h":
                            word_list.append("Ш")
                        else:
                            word_list.append("С")

                elif j == 'h':
                    if i != 0:
                        if [i - 1] == 'c':
                            if [i - 2] == "h":
                                if [i - 3] == "s":
                                    continue
                        else:
                            word_list.append("г")
                    else:
                        word_list.append("г")

                elif j in carp_to_lat_dict:
                    translatinated = carp_translatinate(j)
                    word_list.append(translatinated)
                else:
                    word_list.append(j)

            list_of_translatinated.append(''.join(word_list))
        translatinated_full.append(''.join(list_of_translatinated))

    transliterated_sents = translatinated_full
    return transliterated_sents

# Transliterate from Carpatho-Rusyn to the Latin alphabet


def latin_to_carp(input):
    import re

    def carp_translatinate(x): return ''.join([carp_to_lat_dict[i] for i in x])

    if isinstance(input, str):
        text = input
        translatinated_full = []
        list_of_translatinated = []
        words = re.split(r'(\s+)', text)
        for w in words:
            word_list = []

            for i, j, in enumerate(w):
                # making sure letters we're checking for are within the list's
                # range
                if j == u"\u0361":
                    if 0 <= i + 1 < len(w):
                        if w[i - 1] == "t" and w[i + 1] == "s":
                            word_list.append("ц")
                        elif w[i - 1] == "T" and w[i + 1] == "S":
                            word_list.append("Ц")

                        elif w[i - 1] == "i" and w[i + 1] == "e":
                            word_list.append("є")
                        elif w[i - 1] == "I" and w[i + 1] == "E":
                            word_list.append("Є")

                        elif w[i - 1] == "i" and w[i + 1] == "u":
                            word_list.append("ю")
                        elif w[i - 1] == "I" and w[i + 1] == "U":
                            word_list.append("Ю")

                        elif w[i - 1] == "i" and w[i + 1] == "a":
                            word_list.append("я")
                        elif w[i - 1] == "I" and w[i + 1] == "A":
                            word_list.append("Я")

                        elif w[i - 1] == "z" and w[i + 1] == "h":
                            word_list.append("ж")
                        elif w[i - 1] == "Z" and w[i + 1] == "H":
                            word_list.append("Ж")

                        elif w[i - 1] == "k" and w[i + 1] == "h":
                            word_list.append("х")
                        elif w[i - 1] == "K" and w[i + 1] == "H":
                            word_list.append("Х")

                elif j == "c":
                    if 0 <= i + 1 < len(w):
                        if w[i + 1] == "h":
                            if w[i - 2] != "s" and w[i - 2] != "S":
                                word_list.append("ч")
                elif j == "C":
                    if 0 <= i + 1 < len(w):
                        if w[i + 1] == "h":
                            word_list.append("Ч")

                elif j == "s":
                    if 0 <= i + 3 < len(w):
                        if w[i + 1] == "h":
                            if w[i + 2] == "c":
                                if w[i + 3] == "h":
                                    word_list.append("щ")
                            else:
                                if w[i + 1] == "h":
                                    word_list.append("ш")
                                else:
                                    word_list.append("c")
                        else:
                            word_list.append("c")

                    else:
                        word_list.append("c")

                elif j == "S":
                    if w[i + 1] == "h":
                        if w[i + 2] == "c":
                            if w[i + 3] == "h":
                                word_list.append("Щ")
                    else:
                        if w[i + 1] == "h":
                            word_list.append("Ш")
                        else:
                            word_list.append("С")

                elif j == 'h':
                    if i != 0:
                        if [i - 1] == 'c':
                            if [i - 2] == "h":
                                if [i - 3] == "s":
                                    continue
                        else:
                            word_list.append("г")
                    else:
                        word_list.append("г")

                elif j in carp_to_lat_dict:
                    translatinated = carp_translatinate(j)
                    word_list.append(translatinated)
                else:
                    word_list.append(j)

            list_of_translatinated.append(''.join(word_list))
        translatinated_full.append(''.join(list_of_translatinated))

        transliterated_sents = ' '.join(translatinated_full)
        return transliterated_sents

    elif isinstance(input, list):
        translatinated_full = []
        list_of_translatinated = []
        for txt in input:
            list_of_translatinated = []
            words = re.split(r'(\s+)', txt)
            for w in words:
                word_list = []
                for i, j, in enumerate(w):
                    # making sure letters we're checking for are within the
                    # list's range
                    if j == u"\u0361":
                        if 0 <= i + 1 < len(w):
                            if w[i - 1] == "t" and w[i + 1] == "s":
                                word_list.append("ц")
                            elif w[i - 1] == "T" and w[i + 1] == "S":
                                word_list.append("Ц")

                            elif w[i - 1] == "i" and w[i + 1] == "e":
                                word_list.append("є")
                            elif w[i - 1] == "I" and w[i + 1] == "E":
                                word_list.append("Є")

                            elif w[i - 1] == "i" and w[i + 1] == "u":
                                word_list.append("ю")
                            elif w[i - 1] == "I" and w[i + 1] == "U":
                                word_list.append("Ю")

                            elif w[i - 1] == "i" and w[i + 1] == "a":
                                word_list.append("я")
                            elif w[i - 1] == "I" and w[i + 1] == "A":
                                word_list.append("Я")

                            elif w[i - 1] == "z" and w[i + 1] == "h":
                                word_list.append("ж")
                            elif w[i - 1] == "Z" and w[i + 1] == "H":
                                word_list.append("Ж")

                            elif w[i - 1] == "k" and w[i + 1] == "h":
                                word_list.append("х")
                            elif w[i - 1] == "K" and w[i + 1] == "H":
                                word_list.append("Х")

                    elif j == "c":
                        if 0 <= i + 1 < len(w):
                            if w[i + 1] == "h":
                                if w[i - 2] != "s" and w[i - 2] != "S":
                                    word_list.append("ч")
                    elif j == "C":
                        if 0 <= i + 1 < len(w):
                            if w[i + 1] == "h":
                                word_list.append("Ч")

                    elif 0 <= i + 3 < len(w):
                        # if 0 <= i+1 < len(w):
                        if j == "s":
                            if w[i + 1] == "h":
                                if w[i + 2] == "c":
                                    if w[i + 3] == "h":
                                        word_list.append("щ")
                                else:
                                    if w[i + 1] == "h":
                                        word_list.append("ш")
                        if j == "S":
                            if w[i + 1] == "h":
                                if w[i + 2] == "c":
                                    if w[i + 3] == "h":
                                        word_list.append("Щ")
                            else:
                                if w[i + 1] == "h":
                                    word_list.append("Ш")
                    elif j == 'h':
                        if i != 0:
                            if [i - 1] == 'c':
                                word_list.append("ч")

                            elif [i - 1] == 'C':
                                word_list.append("Ч")
                        else:
                            translatinated = carp_translatinate(j)
                            word_list.append(translatinated)

                    elif j in carp_to_lat_dict:
                        translatinated = carp_translatinate(j)
                        word_list.append(translatinated)
                    else:
                        word_list.append(j)

                list_of_translatinated.append(''.join(word_list))
            translatinated_full.append(''.join(list_of_translatinated))

    transliterated_sents = ' '.join(translatinated_full)
    return transliterated_sents



import unittest
from domovyk import bel, bulg, carp, mac, rus, ukr, serb, church, translit


class TestClient(unittest.TestCase):
    bel_var = "Любя, съешь щипцы, — вздохнёт мэр, — Кайф жгуч! Ѫѣ"
    bel_var_sents = "Любя, съешь щипцы, — вздохнёт мэр, — Кайф жгуч! Разъяренный чтец эгоистично бьёт пятью жердями шустрого фехтовальщика. Ґѣэ."

    bulg_var = "Аз съм учител."
    bulg_var_sents = "Аз съм учител. Иван е лекар."

    carp_var = "Еден јазик никогаш не е доволен."
    carp_var_sents = "Еден јазик никогаш не е доволен. Те молам зборувај побавно."

    mac_var = "Еден јазик никогаш не е доволен."
    mac_var_sents = "Еден јазик никогаш не е доволен. Те молам зборувај побавно."

    rus_var = "Любя, съешь щипцы, — вздохнёт мэр, — Кайф жгуч!"
    rus_var_sents = "Любя, съешь щипцы, — вздохнёт мэр, — Кайф жгуч! Разъяренный чтец эгоистично бьёт пятью жердями шустрого фехтовальщика."

    ukr_var = "Єхидна, ґава, їжак ще й шиплячі плазуни бігцем форсують Янцзи."
    ukr_var_sents = "Єхидна, ґава, їжак ще й шиплячі плазуни бігцем форсують Янцзи. Ви розмовляєте українською?"

    serb_var = "Брза вижљаста лија хоће да ђипи преко њушке флегматичног џукца."
    serb_var_sents = "Брза вижљаста лија хоће да ђипи преко њушке флегматичног џукца. Можеш разговарати са мном на српском."

    church_var = "Кни̑ги но́вагѡ завѣ́та, ѿ матѳе́а, ѿ ма́рка."
    church_var_sents = "Кни̑ги но́вагѡ завѣ́та, ѿ матѳе́а, ѿ ма́рка. Собо́рныѧ посла́нїѧ. Собо́рныѧ посла́нїѧ."

    latin_var_sents = "This is a test. And another test."
    latin_var = "This is a test."

    # Belarusian
    def test_bel_translit_sents(self):
        transliterated = bel.bel_translit_sents(TestClient.bel_var_sents)
        assert transliterated[0] == "Li͡ubi͡a, sʺeshʹ shchīptsy, — vzdokhni͡ot mėr, — Kaĭf z͡hhuch!"
        assert transliterated[2] == "Gěė."

    def test_bel_translit(self):
        transliterated = bel.bel_translit(TestClient.bel_var)
        assert transliterated == "Li͡ubi͡a, sʺeshʹ shchīptsy, — vzdokhni͡ot mėr, — Kaĭf z͡hhuch! Ѫě"

    def test_latin_to_bel_sents(self):
        transliterated = bel.latin_to_bel_sents(TestClient.latin_var_sents)
        assert transliterated[0] == "Тгic ic а теcт."

    def test_latin_to_bel(self):
        transliterated = bel.latin_to_bel(TestClient.latin_var)
        assert transliterated == "Тгic ic а теcт."

    # Bulgarian

    def test_bulg_translit_sents(self):
        transliterated = bulg.bulg_translit_sents(TestClient.bulg_var_sents)
        assert transliterated[0] == "Az sŭm uchitel."
        assert transliterated[1] == "Ivan e lekar."

    def test_bulg_translit(self):
        transliterated = bulg.bulg_translit(TestClient.bulg_var)
        assert transliterated == "Az sŭm uchitel."
    #

    def test_latin_to_bulg_sents(self):
        transliterated = bulg.latin_to_bulg_sents(TestClient.latin_var_sents)
        assert transliterated[0] == "Тhиc иc а теcт."
        assert transliterated[1] == "Анд анотhер теcт."

    def test_latin_to_bulg(self):
        transliterated = bulg.latin_to_bulg(TestClient.latin_var)
        assert transliterated == "Тhиc иc а теcт."

    # Carpatho-Rusyn

    def test_carp_translit_sents(self):
        transliterated = carp.carp_translit_sents(TestClient.carp_var_sents)
        assert transliterated[0] == "Eden јazyk nykohash ne e dovolen."
        assert transliterated[1] == "Te molam zboruvaј pobavno."

    def test_carp_translit(self):
        transliterated = carp.carp_translit(TestClient.carp_var)
        assert transliterated == "Eden јazyk nykohash ne e dovolen."

    def test_latin_to_carp_sents(self):
        transliterated = carp.latin_to_carp_sents(TestClient.latin_var_sents)
        assert transliterated[0] == "Тгic ic а теcт."
        assert transliterated[1] == "Анд анотгер теcт."

    def test_latin_to_carp(self):
        transliterated = carp.latin_to_carp(TestClient.latin_var)
        assert transliterated == "Тгic ic а теcт."

    # Macedonian

    def test_mac_translit_sents(self):
        transliterated = mac.mac_translit_sents(TestClient.mac_var_sents)
        assert transliterated[0] == "Eden jazik nikohaš ne e dovolen."
        assert transliterated[1] == "Te molam zboruvaj pobavno."

    def test_mac_translit(self):
        transliterated = mac.mac_translit(TestClient.mac_var)
        assert transliterated == "Eden jazik nikohaš ne e dovolen."

    def test_latin_to_mac_sents(self):
        transliterated = mac.latin_to_mac_sents(TestClient.latin_var_sents)
        assert transliterated[0] == "Тхис ис а тест."
        assert transliterated[1] == "Анд анотхер тест."

    def test_latin_to_mac(self):
        transliterated = mac.latin_to_mac(TestClient.latin_var)
        assert transliterated == "Тхис ис а тест."

    # Russian

    def test_rus_translit_sents(self):
        transliterated = rus.rus_translit_sents(TestClient.rus_var_sents)
        assert transliterated[0] == "Li͡ubi͡a, sʺeshʹ shchipt͡sy, — vzdokhnёt mėr, — Kaĭf zhguch!"
        assert transliterated[1] == "Razʺi͡arennyĭ chtet͡s ėgoistichno bʹёt pi͡atʹi͡u zherdi͡ami shustrogo fekhtovalʹshchika."

    def test_rus_translit(self):
        transliterated = rus.rus_translit(TestClient.rus_var)
        assert transliterated == "Li͡ubi͡a, sʺeshʹ shchipt͡sy, — vzdokhnёt mėr, — Kaĭf zhguch!"

    def test_latin_to_rus_sents(self):
        transliterated = rus.latin_to_rus_sents(TestClient.latin_var_sents)
        assert transliterated[0] == "Тгиc иc а теcт."
        assert transliterated[1] == "Анд анотгер теcт."

    def test_latin_to_rus(self):
        transliterated = rus.latin_to_rus(TestClient.latin_var)
        assert transliterated == "Тгиc иc а теcт."

    # Serbian

    def test_serb_translit_sents(self):
        transliterated = serb.serb_translit_sents(TestClient.serb_var_sents)
        assert transliterated[0] == "Brza vižljasta lija hoće da đipi preko njuške flegmatičnog džukca."
        assert transliterated[1] == "Možeš razgovarati sa mnom na srpskom."

    def test_serb_translit(self):
        transliterated = serb.serb_translit(TestClient.serb_var)
        assert transliterated == "Brza vižljasta lija hoće da đipi preko njuške flegmatičnog džukca."

    def test_latin_to_serb_sents(self):
        transliterated = serb.latin_to_serb_sents(TestClient.latin_var_sents)
        assert transliterated[0] == "Тхис ис а тест."
        assert transliterated[1] == "Анд анотхер тест."

    def test_latin_to_serb(self):
        transliterated = serb.latin_to_serb(TestClient.latin_var)
        assert transliterated == "Тхис ис а тест."

    # Ukrainian

    def test_ukr_translit_sents(self):
        transliterated = ukr.ukr_translit_sents(TestClient.ukr_var_sents)
        assert transliterated[0] == "I͡Ekhydna, gava, їz͡hak shche ĭ shypli͡achі plazuny bіht͡sem forsui͡utʹ I͡Ant͡szy."
        assert transliterated[1] == "Vy rozmovli͡ai͡ete ukraїnsʹkoi͡u?"

    def test_ukr_translit(self):
        transliterated = ukr.ukr_translit(TestClient.ukr_var)
        assert transliterated == "I͡Ekhydna, gava, їz͡hak shche ĭ shypli͡achі plazuny bіht͡sem forsui͡utʹ I͡Ant͡szy."

    def test_latin_to_ukr_sents(self):
        transliterated = ukr.latin_to_ukr_sents(TestClient.latin_var_sents)
        assert transliterated[0] == "Тгic ic а теcт."
        assert transliterated[1] == "Анд анотгер теcт."

    def test_latin_to_ukr(self):
        transliterated = ukr.latin_to_ukr(TestClient.latin_var)
        assert transliterated == "Тгic ic а теcт."

    # Church Slavonic Tests

    def test_church_translit_sents(self):
        transliterated = church.church_translit_sents(TestClient.church_var_sents)
        assert transliterated[0] == "KnȊhI nóvahō zavě́ta, ō͡t matḟе́a, ō͡t márka."
        assert transliterated[1] == "Sobórnȳę poslánїę."

    def test_church_translit(self):
        transliterated = church.church_translit(TestClient.church_var)
        assert transliterated == "KnȊhI nóvahō zavě́ta, ō͡t matḟе́a, ō͡t márka."

    def test_latin_to_church_sents(self):
        transliterated = church.latin_to_church_sents(TestClient.latin_var_sents)
        assert transliterated[0] == "Тгic ic а тecт."
        assert transliterated[1] == "Анд анотгeр тecт."

    def test_latin_to_church(self):
        transliterated = church.latin_to_church(TestClient.latin_var)
        assert transliterated == "Тгic ic а тecт."

    # Translit Tests

    def test_transliterate(self):
        transliterated = translit.transliterate("Тхис ис а тест.", "rus")
        assert transliterated == "Tkhis is a test."

    def test_translatinate(self):
        transliterated = translit.translatinate("Тhis is a test.", "ukr")
        assert transliterated == "Тгic ic а теcт."

    def test_transliterateSents(self):
        transliterated = translit.transliterateSents(
            "Тгic ic а теcт. Анд анотхер тест.", "bel")
        assert transliterated[1] == "And anotkher test."

    def test_translatinateSents(self):
        transliterated = translit.translatinateSents(
            "Тhis is a test. And another test.", "mac")
        assert transliterated[1] == "Анд анотхер тест."

    if __name__ == '__main__':
        unittest.main()



from domovyk import bel, bulg, carp, mac, rus, ukr, serb, church


def transliterate(var, lang):
    if lang == 'bel':
        transliterated = bel.bel_translit(var)
        return transliterated
    elif lang == 'bulg':
        transliterated = bulg.bulg_translit(var)
        return transliterated
    if lang == 'carp':
        transliterated = carp.carp_translit(var)
        return transliterated
    if lang == 'church':
        transliterated = church.church_translit(var)
        return transliterated
    if lang == 'mac':
        transliterated = mac.mac_translit(var)
        return transliterated
    if lang == 'rus':
        transliterated = rus.rus_translit(var)
        return transliterated
    if lang == 'ukr':
        transliterated = ukr.ukr_translit(var)
        return transliterated
    if lang == 'serb':
        transliterated = serb.serb_translit(var)
        return transliterated



def translatinate(var, lang):
    if lang == 'bel':
        translatinated = bel.latin_to_bel(var)
        return translatinated
    elif lang == 'bulg':
        translatinated = bulg.latin_to_bulg(var)
        return translatinated
    if lang == 'carp':
        translatinated = carp.latin_to_carp(var)
        return translatinated
    if lang == 'church':
        translatinated = church.latin_to_church(var)
        return translatinated
    if lang == 'mac':
        translatinated = mac.latin_to_mac(var)
        return translatinated
    if lang == 'rus':
        translatinated = rus.latin_to_rus(var)
        return translatinated
    if lang == 'ukr':
        translatinated = ukr.latin_to_ukr(var)
        return translatinated
    if lang == 'serb':
        translatinated = serb.latin_to_serb(var)
        return translatinated


def transliterateSents(var, lang):
    if lang == 'bel':
        transliterated = bel.bel_translit_sents(var)
        return transliterated
    elif lang == 'bulg':
        transliterated = bulg.bulg_translit_sents(var)
        return transliterated
    if lang == 'carp':
        transliterated = carp.carp_translit_sents(var)
        return transliterated
    if lang == 'church':
        transliterated = church.church_translit_sents(var)
        return transliterated
    if lang == 'mac':
        transliterated = mac.mac_translit_sents(var)
        return transliterated
    if lang == 'rus':
        transliterated = rus.rus_translit_sents(var)
        return transliterated
    if lang == 'ukr':
        transliterated = ukr.ukr_translit_sents(var)
        return transliterated
    if lang == 'serb':
        transliterated = serb.serb_translit_sents(var)
        return transliterated


def translatinateSents(var, lang):
    if lang == 'bel':
        translatinated = bel.latin_to_bel_sents(var)
        return translatinated
    elif lang == 'bulg':
        translatinated = bulg.latin_to_bulg_sents(var)
        return translatinated
    if lang == 'carp':
        translatinated = carp.latin_to_carp_sents(var)
        return translatinated
    if lang == 'church':
        translatinated = church.latin_to_church_sents(var)
        return translatinated
    if lang == 'mac':
        translatinated = mac.latin_to_mac_sents(var)
        return translatinated
    if lang == 'rus':
        translatinated = rus.latin_to_rus_sents(var)
        return translatinated
    if lang == 'ukr':
        translatinated = ukr.latin_to_ukr_sents(var)
        return translatinated
    if lang == 'serb':
        translatinated = serb.latin_to_serb_sents(var)
        return translatinated
